package com.example.shikan.eldelbar;

import android.content.Context;
import android.support.annotation.NonNull;
import android.support.v7.widget.CardView;
import android.support.v7.widget.RecyclerView;
import android.view.ContextMenu;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.TextView;
import android.widget.Toast;

import com.example.shikan.eldelbar.database.entidades.Gasto;

import java.util.ArrayList;

import static com.firebase.ui.auth.AuthUI.getApplicationContext;

public class ListaGastosRecyclerViewAdapter extends RecyclerView.Adapter<ListaGastosRecyclerViewAdapter.ViewHolder> implements View.OnClickListener {

    //Datos que hay que representar en el RecyclerView
    private ArrayList<Gasto> listaGastos;
    private Context context;

    //Evento click
    View.OnClickListener listener;

    //Posiciones par e impar para mostrar un layout u otro
    private final static int PAR = 0;
    private final static int IMPAR = 1;


    //constructor
    public ListaGastosRecyclerViewAdapter( ArrayList<Gasto> listaGastos, Context context){
        this.listaGastos = listaGastos;
        this.context = context;
    }

    //Tamaño de la lista
    @Override
    public int getItemCount(){
        return listaGastos.size();
    }

    public void setGastos(ArrayList<Gasto> gastos){
        this.listaGastos = gastos;
        notifyDataSetChanged();
    }

    //Obtenemos la posición del item
    @Override
    public int getItemViewType(int position) {
        int type;
        if ((position+2) % 2 == 0) {
            type = PAR;
        } else {
            type = IMPAR;
        }
        return type;
    }

    /**
     * Método para crear los diferentes Holders según el tipo de vista
     *
     * @param viewGroup ViewGroup container del item
     * @param viewType tipo de vista
     * @return viewHolder que se inflará
     */

    //Si es par, layout par, si es impar, layout impar
    @Override
    public ViewHolder onCreateViewHolder(ViewGroup parent, int viewType) {

        //ViewHolder viewHolder = null;

        View view = null;

        if (viewType == PAR) {
            view = LayoutInflater.from(parent.getContext())
                    .inflate(R.layout.cell_gasto, parent, false);

        } else if (viewType == IMPAR) {
            view = LayoutInflater.from(parent.getContext())
                    .inflate(R.layout.cell_gasto_impar, parent, false);

        }

        view.setOnClickListener(this);

        return new ViewHolder(view);
    }

    /**
     * Este método llama internamente a onBindViewHolder(ViewHolder, int) para actualizar
     * el contenido de RecyclerView.ViewHolder con el item en esa posición
     * y setea los campos privados necesarios en el RecyclerView.
     *
     * @param viewHolder Tipo de RecyclerView.ViewHolder para rellenar
     * @param position posición del item
     */

    @Override
    public void onBindViewHolder(@NonNull ViewHolder holder, int position) {
        holder.gasto = listaGastos.get(position);
        holder.tv_hora.setText(listaGastos.get(position).getHora());
        holder.tv_descripcion.setText(listaGastos.get(position).getDescripcion());
        holder.tv_precio.setText(new Double(listaGastos.get(position).getPrecio()).toString());
    }

    public void setOnClickListener(View.OnClickListener listener){
        this.listener = listener;
    }

    //Implementamos el click de cada elemento de la lista
   @Override
    public void onClick(View view) {
        if(listener != null)
            listener.onClick(view);
    }


    // Provide a reference to the views for each data item
    // Complex data items may need more than one view per item, and
    // you provide access to all the views for a data item in a view holder
    public static class ViewHolder extends RecyclerView.ViewHolder{

        // Cada dato lo asociamos con el elemento del layout del RV
        public View view;
        public TextView tv_hora;
        public TextView tv_precio;
        public TextView tv_descripcion;
        public Gasto gasto;


        public ViewHolder(View view) {
            super(view);
            this.view = view;
            tv_hora = view.findViewById(R.id.RV_hora);
            tv_precio = view.findViewById(R.id.RV_Precio);
            tv_descripcion = view.findViewById(R.id.RV_Descripcion);

        }
    }

    @Override
    public void onAttachedToRecyclerView(RecyclerView recyclerView) {
        super.onAttachedToRecyclerView(recyclerView);
    }

}
