package com.example.shikan.eldelbar;

import android.content.Context;
import android.support.annotation.NonNull;
import android.support.v7.widget.RecyclerView;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;

import com.example.shikan.eldelbar.database.entidades.Sesion;

import java.util.ArrayList;

public class ListaSesionesRecyclerviewAdapter extends RecyclerView.Adapter<ListaSesionesRecyclerviewAdapter.ViewHolder>
implements View.OnClickListener{

    //Datos que hay que representar en el RecyclerView
    private ArrayList<Sesion> listaSesiones;
    private Context context;

    //Posiciones par e impar para mostrar un layout u otro
    private final static int PAR = 0;
    private final static int IMPAR = 1;

    //Evento click
    View.OnClickListener listener;

    //constructor
    public ListaSesionesRecyclerviewAdapter( ArrayList<Sesion> listaSesiones, Context context){
        this.listaSesiones = listaSesiones;
        this.context = context;
    }

    //Tamaño de la lista
    @Override
    public int getItemCount(){
        return listaSesiones.size();
    }

    public void setSesiones(ArrayList<Sesion> sesiones){
        this.listaSesiones = sesiones;
        notifyDataSetChanged();
    }

    //Obtenemos la posición del item
    @Override
    public int getItemViewType(int position) {
        int type;
        if (position % 2 == 0) {
            type = PAR;
        } else {
            type = IMPAR;
        }
        return type;
    }

    /*public int getCurrentPosition(ArrayList<Sesion> sesiones){

    }*/

    /**
     * Método para crear los diferentes Holders según el tipo de vista
     *
     * @param viewGroup ViewGroup container del item
     * @param viewType tipo de vista
     * @return viewHolder que se inflará
     */

    //Si es par, layout par, si es impar, layout impar
    @Override
    public ViewHolder onCreateViewHolder(ViewGroup parent, int viewType) {

        //ViewHolder viewHolder = null;

        View view = null;

        if (viewType == PAR) {
            view = LayoutInflater.from(parent.getContext())
                    .inflate(R.layout.cell_sesion_par, parent, false);

        } else if (viewType == IMPAR) {
            view = LayoutInflater.from(parent.getContext())
                    .inflate(R.layout.cell_sesion_impar, parent, false);

        }
        view.setOnClickListener(this);

        return new ViewHolder(view);
    }

    /**
     * Este método llama internamente a onBindViewHolder(ViewHolder, int) para actualizar
     * el contenido de RecyclerView.ViewHolder con el item en esa posición
     * y setea los campos privados necesarios en el RecyclerView.
     *
     * @param viewHolder Tipo de RecyclerView.ViewHolder para rellenar
     * @param position posición del item
     */

    @Override
    public void onBindViewHolder(@NonNull ViewHolder holder, int position) {
        holder.sesion = listaSesiones.get(position);
        holder.tv_fecha.setText(listaSesiones.get(position).getFecha_hora_inicio().substring(0,10));
        holder.tv_descripcion.setText(listaSesiones.get(position).getTitulo());
    }

    public void setOnClickListener(View.OnClickListener listener){
        this.listener = listener;
    }

    //Implementamos el click de cada elemento de la lista
    @Override
    public void onClick(View view) {
        if(listener != null)
            listener.onClick(view);
    }


    // Provide a reference to the views for each data item
    // Complex data items may need more than one view per item, and
    // you provide access to all the views for a data item in a view holder
    public static class ViewHolder extends RecyclerView.ViewHolder {

        // Cada dato lo asociamos con el elemento del layout del RV
        public final View view;
        public final TextView tv_fecha;
        public final TextView tv_descripcion;
        public Sesion sesion;


        public ViewHolder(View view) {
            super(view);
            this.view = view;
            tv_fecha = view.findViewById(R.id.RV_fecha);
            tv_descripcion = view.findViewById(R.id.RV_Descripcion);

        }
    }

    @Override
    public void onAttachedToRecyclerView(RecyclerView recyclerView) {
        super.onAttachedToRecyclerView(recyclerView);
    }
}
