package com.example.shikan.eldelbar.database;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;
import android.util.Log;

import com.example.shikan.eldelbar.database.entidades.Gasto;
import com.example.shikan.eldelbar.database.entidades.Sesion;

import java.util.ArrayList;
import java.util.List;

public class EldelbarDB extends SQLiteOpenHelper {
    public static final String DATABASE_NAME = "Eldelbar_DB";
    // Database Version
    private static final int DATABASE_VERSION = 1;

    //Campos tabla Sesion
    public static final String TABLA_SESION = "Sesion";
    public static final String SESION_ID_SESION_PK = "id_sesion";
    public static final String SESION_PRESUPUESTO = "presupuesto";
    public static final String SESION_TOTAL_GASTADO = "total_gastado";
    public static final String SESION_CONSEGUIDO = "conseguido";
    public static final String SESION_FECHA_HORA_INICIO = "fecha_hora_inicio";
    public static final String SESION_FECHA_HORA_FIN = "fecha_hora_fin";
    public static final String SESION_TERMINADA = "terminada";
    public static final String SESION_TITULO = "titulo";

    public static final String CREAR_TABLA_SESION = "CREATE TABLE "+
            TABLA_SESION+" ("+SESION_ID_SESION_PK+ " TEXT PRIMARY KEY, "+
            SESION_PRESUPUESTO+ " DOUBLE, "+
            SESION_TOTAL_GASTADO+ " DOUBLE, "+
            SESION_CONSEGUIDO+ " INTEGER, "+
            SESION_FECHA_HORA_INICIO+ " TEXT, "+
            SESION_FECHA_HORA_FIN+" TEXT, "+
            SESION_TERMINADA+" INTEGER,"+
            SESION_TITULO+" TEXT )";


    //Campos tabla Gastos
    public static final String TABLA_GASTOS = "Gastos";
    public static final String GASTOS_ID_GASTO = "id_gasto";
    public static final String GASTOS_ID_SESION_FK = "id_sesion";
    public static final String GASTOS_HORA = "hora";
    public static final String GASTOS_FECHA = "fecha";
    public static final String GASTOS_DESCRIPCION = "descripcion";
    public static final String GASTOS_PRECIO = "precio";
    public static final String GASTOS_NOMBRE_LOCAL = "nombre_local";
    public static final String GASTOS_DIRECCION_LOCAL = "direccion_local";
    public static final String GASTOS_LOCALIZACION_LOCAL = "localizacion_local";

    public static final String CREAR_TABLA_GASTOS = "CREATE TABLE "+
            TABLA_GASTOS+" ("+
            GASTOS_ID_GASTO+" INTEGER PRIMARY KEY AUTOINCREMENT,"+
            GASTOS_FECHA+ " TEXT,"+
            GASTOS_HORA+" TEXT, "+
            GASTOS_PRECIO+" DOUBLE, "+
            GASTOS_DESCRIPCION+" TEXT, "+
            GASTOS_ID_SESION_FK +" TEXT, "+
            GASTOS_NOMBRE_LOCAL+" TEXT, "+
            GASTOS_DIRECCION_LOCAL+" TEXT, "+
            GASTOS_LOCALIZACION_LOCAL+" TEXT ) ";

    public EldelbarDB(Context context){
        super(context, DATABASE_NAME, null, DATABASE_VERSION);
    }

    @Override
    public void onCreate(SQLiteDatabase db) {
        db.execSQL(CREAR_TABLA_SESION);
        Log.d("BD","Tabla Sesion creada");
        db.execSQL(CREAR_TABLA_GASTOS);
        Log.d("BD","Tabla Gastos creada");
    }

    @Override
    public void onUpgrade(SQLiteDatabase db, int versionAntigua, int versionNueva) {
        db.execSQL("DROP TABLE IF EXISTS "+TABLA_SESION);
        db.execSQL("DROP TABLE IF EXISTS "+TABLA_GASTOS);
        onCreate(db);
    }

    /*
     * Sesion = {Id_Sesion+total_gastado+conseguido?+fecha_hora_inicio+fecha_hora_fin}
     *
     */

    /*Agregamos datos a la tabla Sesion
    *
    * La tabla se empieza a rellenar, pero no se completa hasta que finaliza la sesion: El usuario la ha de finalizar
    * */
    public void AgregarSesion(String Id_Sesion, double presupuesto, String fecha_hora_inicio, int terminada, String titulo){
        SQLiteDatabase db = this.getWritableDatabase();
        ContentValues values = new ContentValues();

        double total_gastado = 0;
        int conseguido = 0;
        String fecha_hora_fin = "";

        Log.d("BD","En AgregarSesion");

        values.put(SESION_ID_SESION_PK, Id_Sesion);
        values.put(SESION_PRESUPUESTO, presupuesto);
        values.put(SESION_TOTAL_GASTADO, total_gastado);
        values.put(SESION_CONSEGUIDO, conseguido);
        values.put(SESION_FECHA_HORA_INICIO, fecha_hora_inicio);
        values.put(SESION_FECHA_HORA_FIN, fecha_hora_fin);
        values.put(SESION_TERMINADA, terminada);
        values.put(SESION_TITULO, titulo);

        Log.d("BD","En AgregarSesion?");

        db.insert(TABLA_SESION,null, values);

        db.close();
    }

    public void TerminarSesion(String Id_Sesion, double totalGastado, int conseguido, String fecha_hora_fin, int terminada){
        SQLiteDatabase db = this.getWritableDatabase();
        ContentValues values = new ContentValues();

        db.execSQL("Update "+TABLA_SESION+" SET "+
                SESION_TOTAL_GASTADO+" = "+totalGastado+","+
                SESION_CONSEGUIDO+" = "+conseguido+", "+
                SESION_FECHA_HORA_FIN+" = '"+fecha_hora_fin+"', "+
                SESION_TERMINADA+" = "+terminada+
                " Where "+SESION_ID_SESION_PK+" = '"+Id_Sesion+"'");

        db.close();
    }

    /*
    *  Gastos = {Id_Sesion+Fecha+Hora+Precio+Descripcion}
    */

    //Agregamos datos a la tabla Gastos
    public void AgregarGasto(String Id_Sesion, String fecha, String hora, double precio, String descripcion, String nombreLocal, String direccionLocal, String localizacionLocal){
        SQLiteDatabase db = this.getWritableDatabase();
        ContentValues values = new ContentValues();

        values.put(GASTOS_FECHA, fecha);
        values.put(GASTOS_HORA, hora);
        values.put(GASTOS_PRECIO, precio);
        values.put(GASTOS_DESCRIPCION, descripcion);
        values.put(GASTOS_ID_SESION_FK, Id_Sesion);
        values.put(GASTOS_NOMBRE_LOCAL, nombreLocal);
        values.put(GASTOS_DIRECCION_LOCAL, direccionLocal);
        values.put(GASTOS_LOCALIZACION_LOCAL, localizacionLocal);

        Log.d("Recycler","AgregarGasto: "+values);
        db.insert(TABLA_GASTOS,null,values);
        db.close();
    }

    //Obtener todos los gastos
    public ArrayList<Gasto> obtenerGastos(String id_sesion){

        Log.d("Recycler","id_sesion: "+id_sesion);
        ArrayList<Gasto> listaGastos = new ArrayList<>();
        SQLiteDatabase db = this.getReadableDatabase();

        /*Hacemos la consulta mediante el cursor

        SELECT precio, hora, descripcion
        FROM gasto g, sesion, s
        WHERE g.id_sesion = s.id_sesion
         */

        Cursor c = db.rawQuery("SELECT *"+
                " FROM "+TABLA_GASTOS+
                " WHERE "+GASTOS_ID_SESION_FK+" = "+"'"+id_sesion+"'",null);

        if(c.moveToFirst()){
            do{
                int id_gasto = c.getInt(c.getColumnIndex(GASTOS_ID_GASTO));
                String fecha = c.getString(c.getColumnIndex(GASTOS_FECHA));
                String hora = c.getString(c.getColumnIndex(GASTOS_HORA));
                String descripcion = c.getString(c.getColumnIndex(GASTOS_DESCRIPCION));
                double precio = c.getDouble(c.getColumnIndex(GASTOS_PRECIO));
                String nombreLocal = c.getString(c.getColumnIndex(GASTOS_NOMBRE_LOCAL));
                String direccionLocal = c.getString(c.getColumnIndex(GASTOS_DIRECCION_LOCAL));
                String localizacionLocal = c.getString(c.getColumnIndex(GASTOS_LOCALIZACION_LOCAL));

                listaGastos.add(new Gasto(id_gasto, id_sesion, fecha, hora, precio, descripcion, nombreLocal, direccionLocal, localizacionLocal));
                Log.d("Recycler","Precio: "+precio);
            }while(c.moveToNext());
            //Cerramos cursor
            c.close();
        }

        Log.d("Obtenergastos","ObtenerListaGastos: "+listaGastos);

        return listaGastos;
    }

    public ArrayList<Sesion> ObtenerTituloSesiones(){
        ArrayList<Sesion> listaSesiones = new ArrayList<>();
        SQLiteDatabase db = this.getReadableDatabase();

        Cursor c = db.rawQuery("SELECT "+SESION_TITULO+","+SESION_FECHA_HORA_INICIO+","+SESION_ID_SESION_PK+","+SESION_TOTAL_GASTADO+","+SESION_CONSEGUIDO+","+SESION_PRESUPUESTO+
                " FROM "+TABLA_SESION,null);



        if(c.moveToFirst()){
            do{
                String id_sesion = c.getString(c.getColumnIndex(SESION_ID_SESION_PK));
                String titulo_sesion = c.getString(c.getColumnIndex(SESION_TITULO));
                String fecha_hora_sesion = c.getString(c.getColumnIndex(SESION_FECHA_HORA_INICIO)).substring(0,10);
                Double total_gastado = c.getDouble(c.getColumnIndex(SESION_TOTAL_GASTADO));
                Double presupuesto = c.getDouble(c.getColumnIndex(SESION_PRESUPUESTO));
                int conseguido = c.getInt(c.getColumnIndex(SESION_CONSEGUIDO));

                listaSesiones.add(new Sesion(id_sesion,fecha_hora_sesion,null,total_gastado,conseguido,presupuesto,0,titulo_sesion));
            }while(c.moveToNext());
            //Cerramos cursor
            c.close();
        }

        return listaSesiones;

    }

    public void eliminarGasto(String id_sesion, int id_gasto){

        SQLiteDatabase db = this.getWritableDatabase();

       /* DELETE FROM GASTOS
        WHERE id_sesion = id_sesion AND id_gasto = id_gasto
        */

       //Eliminamos de BD
        db.execSQL("DELETE FROM "+TABLA_GASTOS+
                " WHERE "+GASTOS_ID_GASTO+" = "+id_gasto+" AND "+GASTOS_ID_SESION_FK+" = '"+id_sesion+"'");

        db.close();
    }


}
